@@ -10,6 +10,6 @@ void stringCompare(STRINGVAR_ *lhs, STRINGVAR_ const *rhs)
                                 /* the non-16 bit return value may have its */
                                 /* lower 16 bits set to zero (as happened   */
                                 /* on the powerpc                           */
-    *lhs = intConstructor_i(ret < 0 ? -1 : ret > 0 ? 1 : 0);
+    *lhs = *intConstructor_i(ret < 0 ? -1 : ret > 0 ? 1 : 0);
 }
 
